Cloning a Starter Package
-------------------------

We have several packages available to start from:

* `Empty Package <https://github.com/steamship-packages/empty-package>`_ - Bare-bones starter package shell
* `Prompt API template <https://github.com/steamship-packages/prompt-api-template>`_ - Turn a GPT prompt into an API
* `Chat analytics <https://github.com/steamship-packages/chat-analytics>`_ - Cluster chatroom messages into conversations and classify intent and sentiment
* `Ticket Tagging <https://github.com/steamship-packages/ticket-tagging-api>`_ - Tag service tickets with a zero-shot classifier, then transition to a trained model
* `Audio to Markdown <https://github.com/steamship-packages/audio-markdown>`_ - Create a markdown file from an audio transcript, using specific command words

